aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.PMR/Stubs
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2020-12-01 19:26:32 +0200
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2020-12-01 19:26:32 +0200
commit68ec47fb04c19139f8e39343689201a9f089ad8c (patch)
treee23dd24478a97faa373a2a58ae4d865882447f4d /Software/Visual_Studio/Tango.PMR/Stubs
parent45a7a7319bbae1a2ab5cfc93d7a2507cccd8770e (diff)
downloadTango-68ec47fb04c19139f8e39343689201a9f089ad8c.tar.gz
Tango-68ec47fb04c19139f8e39343689201a9f089ad8c.zip
Implemented machine events emulation via FSE.
Added support for event 5099. Updated event rev to 28. Added 3 & 4 dancer types for X4.
Diffstat (limited to 'Software/Visual_Studio/Tango.PMR/Stubs')
-rw-r--r--Software/Visual_Studio/Tango.PMR/Stubs/ProcedureRequest.cs138
-rw-r--r--Software/Visual_Studio/Tango.PMR/Stubs/ProcedureResponse.cs110
2 files changed, 74 insertions, 174 deletions
diff --git a/Software/Visual_Studio/Tango.PMR/Stubs/ProcedureRequest.cs b/Software/Visual_Studio/Tango.PMR/Stubs/ProcedureRequest.cs
index 771aaf4f0..0070fbe33 100644
--- a/Software/Visual_Studio/Tango.PMR/Stubs/ProcedureRequest.cs
+++ b/Software/Visual_Studio/Tango.PMR/Stubs/ProcedureRequest.cs
@@ -22,15 +22,14 @@ namespace Tango.PMR.Stubs {
static ProcedureRequestReflection() {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
- "ChZQcm9jZWR1cmVSZXF1ZXN0LnByb3RvEg9UYW5nby5QTVIuU3R1YnMicQoQ",
+ "ChZQcm9jZWR1cmVSZXF1ZXN0LnByb3RvEg9UYW5nby5QTVIuU3R1YnMiUgoQ",
"UHJvY2VkdXJlUmVxdWVzdBIMCgRUeXBlGAEgASgFEg8KB1RpbWVvdXQYAiAB",
- "KAUSDgoGUGFyYW0xGAMgASgCEg4KBlBhcmFtMhgEIAEoAhIOCgZQYXJhbTMY",
- "BSABKAISDgoGUGFyYW00GAYgASgCQhsKGWNvbS50d2luZS50YW5nby5wbXIu",
- "c3R1YnNiBnByb3RvMw=="));
+ "KAUSEAoIVGVzdE5hbWUYAyABKAkSDQoFUGFyYW0YBCADKAJCGwoZY29tLnR3",
+ "aW5lLnRhbmdvLnBtci5zdHVic2IGcHJvdG8z"));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Stubs.ProcedureRequest), global::Tango.PMR.Stubs.ProcedureRequest.Parser, new[]{ "Type", "Timeout", "Param1", "Param2", "Param3", "Param4" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Stubs.ProcedureRequest), global::Tango.PMR.Stubs.ProcedureRequest.Parser, new[]{ "Type", "Timeout", "TestName", "Param" }, null, null, null)
}));
}
#endregion
@@ -63,10 +62,8 @@ namespace Tango.PMR.Stubs {
public ProcedureRequest(ProcedureRequest other) : this() {
type_ = other.type_;
timeout_ = other.timeout_;
- param1_ = other.param1_;
- param2_ = other.param2_;
- param3_ = other.param3_;
- param4_ = other.param4_;
+ testName_ = other.testName_;
+ param_ = other.param_.Clone();
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -96,48 +93,25 @@ namespace Tango.PMR.Stubs {
}
}
- /// <summary>Field number for the "Param1" field.</summary>
- public const int Param1FieldNumber = 3;
- private float param1_;
+ /// <summary>Field number for the "TestName" field.</summary>
+ public const int TestNameFieldNumber = 3;
+ private string testName_ = "";
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public float Param1 {
- get { return param1_; }
+ public string TestName {
+ get { return testName_; }
set {
- param1_ = value;
+ testName_ = pb::ProtoPreconditions.CheckNotNull(value, "value");
}
}
- /// <summary>Field number for the "Param2" field.</summary>
- public const int Param2FieldNumber = 4;
- private float param2_;
+ /// <summary>Field number for the "Param" field.</summary>
+ public const int ParamFieldNumber = 4;
+ private static readonly pb::FieldCodec<float> _repeated_param_codec
+ = pb::FieldCodec.ForFloat(34);
+ private readonly pbc::RepeatedField<float> param_ = new pbc::RepeatedField<float>();
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public float Param2 {
- get { return param2_; }
- set {
- param2_ = value;
- }
- }
-
- /// <summary>Field number for the "Param3" field.</summary>
- public const int Param3FieldNumber = 5;
- private float param3_;
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public float Param3 {
- get { return param3_; }
- set {
- param3_ = value;
- }
- }
-
- /// <summary>Field number for the "Param4" field.</summary>
- public const int Param4FieldNumber = 6;
- private float param4_;
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public float Param4 {
- get { return param4_; }
- set {
- param4_ = value;
- }
+ public pbc::RepeatedField<float> Param {
+ get { return param_; }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -155,10 +129,8 @@ namespace Tango.PMR.Stubs {
}
if (Type != other.Type) return false;
if (Timeout != other.Timeout) return false;
- if (Param1 != other.Param1) return false;
- if (Param2 != other.Param2) return false;
- if (Param3 != other.Param3) return false;
- if (Param4 != other.Param4) return false;
+ if (TestName != other.TestName) return false;
+ if(!param_.Equals(other.param_)) return false;
return true;
}
@@ -167,10 +139,8 @@ namespace Tango.PMR.Stubs {
int hash = 1;
if (Type != 0) hash ^= Type.GetHashCode();
if (Timeout != 0) hash ^= Timeout.GetHashCode();
- if (Param1 != 0F) hash ^= Param1.GetHashCode();
- if (Param2 != 0F) hash ^= Param2.GetHashCode();
- if (Param3 != 0F) hash ^= Param3.GetHashCode();
- if (Param4 != 0F) hash ^= Param4.GetHashCode();
+ if (TestName.Length != 0) hash ^= TestName.GetHashCode();
+ hash ^= param_.GetHashCode();
return hash;
}
@@ -189,22 +159,11 @@ namespace Tango.PMR.Stubs {
output.WriteRawTag(16);
output.WriteInt32(Timeout);
}
- if (Param1 != 0F) {
- output.WriteRawTag(29);
- output.WriteFloat(Param1);
- }
- if (Param2 != 0F) {
- output.WriteRawTag(37);
- output.WriteFloat(Param2);
- }
- if (Param3 != 0F) {
- output.WriteRawTag(45);
- output.WriteFloat(Param3);
- }
- if (Param4 != 0F) {
- output.WriteRawTag(53);
- output.WriteFloat(Param4);
+ if (TestName.Length != 0) {
+ output.WriteRawTag(26);
+ output.WriteString(TestName);
}
+ param_.WriteTo(output, _repeated_param_codec);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -216,18 +175,10 @@ namespace Tango.PMR.Stubs {
if (Timeout != 0) {
size += 1 + pb::CodedOutputStream.ComputeInt32Size(Timeout);
}
- if (Param1 != 0F) {
- size += 1 + 4;
- }
- if (Param2 != 0F) {
- size += 1 + 4;
- }
- if (Param3 != 0F) {
- size += 1 + 4;
- }
- if (Param4 != 0F) {
- size += 1 + 4;
+ if (TestName.Length != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeStringSize(TestName);
}
+ size += param_.CalculateSize(_repeated_param_codec);
return size;
}
@@ -242,18 +193,10 @@ namespace Tango.PMR.Stubs {
if (other.Timeout != 0) {
Timeout = other.Timeout;
}
- if (other.Param1 != 0F) {
- Param1 = other.Param1;
- }
- if (other.Param2 != 0F) {
- Param2 = other.Param2;
- }
- if (other.Param3 != 0F) {
- Param3 = other.Param3;
- }
- if (other.Param4 != 0F) {
- Param4 = other.Param4;
+ if (other.TestName.Length != 0) {
+ TestName = other.TestName;
}
+ param_.Add(other.param_);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -272,20 +215,13 @@ namespace Tango.PMR.Stubs {
Timeout = input.ReadInt32();
break;
}
- case 29: {
- Param1 = input.ReadFloat();
+ case 26: {
+ TestName = input.ReadString();
break;
}
+ case 34:
case 37: {
- Param2 = input.ReadFloat();
- break;
- }
- case 45: {
- Param3 = input.ReadFloat();
- break;
- }
- case 53: {
- Param4 = input.ReadFloat();
+ param_.AddEntriesFrom(input, _repeated_param_codec);
break;
}
}
diff --git a/Software/Visual_Studio/Tango.PMR/Stubs/ProcedureResponse.cs b/Software/Visual_Studio/Tango.PMR/Stubs/ProcedureResponse.cs
index afbad9a4d..85c14a6a1 100644
--- a/Software/Visual_Studio/Tango.PMR/Stubs/ProcedureResponse.cs
+++ b/Software/Visual_Studio/Tango.PMR/Stubs/ProcedureResponse.cs
@@ -22,15 +22,14 @@ namespace Tango.PMR.Stubs {
static ProcedureResponseReflection() {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
- "ChdQcm9jZWR1cmVSZXNwb25zZS5wcm90bxIPVGFuZ28uUE1SLlN0dWJzIm4K",
+ "ChdQcm9jZWR1cmVSZXNwb25zZS5wcm90bxIPVGFuZ28uUE1SLlN0dWJzIlkK",
"EVByb2NlZHVyZVJlc3BvbnNlEgwKBFR5cGUYASABKAUSDAoEVGltZRgCIAEo",
- "BRITCgtSZXBseVZhbHVlMRgDIAEoAhITCgtSZXBseVZhbHVlMhgEIAEoAhIT",
- "CgtSZXBseVZhbHVlMxgFIAEoAkIbChljb20udHdpbmUudGFuZ28ucG1yLnN0",
- "dWJzYgZwcm90bzM="));
+ "BRIUCgxSZXBseU1lc3NhZ2UYAyABKAkSEgoKUmVwbHlWYWx1ZRgEIAMoAkIb",
+ "Chljb20udHdpbmUudGFuZ28ucG1yLnN0dWJzYgZwcm90bzM="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Stubs.ProcedureResponse), global::Tango.PMR.Stubs.ProcedureResponse.Parser, new[]{ "Type", "Time", "ReplyValue1", "ReplyValue2", "ReplyValue3" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Stubs.ProcedureResponse), global::Tango.PMR.Stubs.ProcedureResponse.Parser, new[]{ "Type", "Time", "ReplyMessage", "ReplyValue" }, null, null, null)
}));
}
#endregion
@@ -63,9 +62,8 @@ namespace Tango.PMR.Stubs {
public ProcedureResponse(ProcedureResponse other) : this() {
type_ = other.type_;
time_ = other.time_;
- replyValue1_ = other.replyValue1_;
- replyValue2_ = other.replyValue2_;
- replyValue3_ = other.replyValue3_;
+ replyMessage_ = other.replyMessage_;
+ replyValue_ = other.replyValue_.Clone();
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -95,37 +93,25 @@ namespace Tango.PMR.Stubs {
}
}
- /// <summary>Field number for the "ReplyValue1" field.</summary>
- public const int ReplyValue1FieldNumber = 3;
- private float replyValue1_;
+ /// <summary>Field number for the "ReplyMessage" field.</summary>
+ public const int ReplyMessageFieldNumber = 3;
+ private string replyMessage_ = "";
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public float ReplyValue1 {
- get { return replyValue1_; }
+ public string ReplyMessage {
+ get { return replyMessage_; }
set {
- replyValue1_ = value;
+ replyMessage_ = pb::ProtoPreconditions.CheckNotNull(value, "value");
}
}
- /// <summary>Field number for the "ReplyValue2" field.</summary>
- public const int ReplyValue2FieldNumber = 4;
- private float replyValue2_;
+ /// <summary>Field number for the "ReplyValue" field.</summary>
+ public const int ReplyValueFieldNumber = 4;
+ private static readonly pb::FieldCodec<float> _repeated_replyValue_codec
+ = pb::FieldCodec.ForFloat(34);
+ private readonly pbc::RepeatedField<float> replyValue_ = new pbc::RepeatedField<float>();
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public float ReplyValue2 {
- get { return replyValue2_; }
- set {
- replyValue2_ = value;
- }
- }
-
- /// <summary>Field number for the "ReplyValue3" field.</summary>
- public const int ReplyValue3FieldNumber = 5;
- private float replyValue3_;
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public float ReplyValue3 {
- get { return replyValue3_; }
- set {
- replyValue3_ = value;
- }
+ public pbc::RepeatedField<float> ReplyValue {
+ get { return replyValue_; }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -143,9 +129,8 @@ namespace Tango.PMR.Stubs {
}
if (Type != other.Type) return false;
if (Time != other.Time) return false;
- if (ReplyValue1 != other.ReplyValue1) return false;
- if (ReplyValue2 != other.ReplyValue2) return false;
- if (ReplyValue3 != other.ReplyValue3) return false;
+ if (ReplyMessage != other.ReplyMessage) return false;
+ if(!replyValue_.Equals(other.replyValue_)) return false;
return true;
}
@@ -154,9 +139,8 @@ namespace Tango.PMR.Stubs {
int hash = 1;
if (Type != 0) hash ^= Type.GetHashCode();
if (Time != 0) hash ^= Time.GetHashCode();
- if (ReplyValue1 != 0F) hash ^= ReplyValue1.GetHashCode();
- if (ReplyValue2 != 0F) hash ^= ReplyValue2.GetHashCode();
- if (ReplyValue3 != 0F) hash ^= ReplyValue3.GetHashCode();
+ if (ReplyMessage.Length != 0) hash ^= ReplyMessage.GetHashCode();
+ hash ^= replyValue_.GetHashCode();
return hash;
}
@@ -175,18 +159,11 @@ namespace Tango.PMR.Stubs {
output.WriteRawTag(16);
output.WriteInt32(Time);
}
- if (ReplyValue1 != 0F) {
- output.WriteRawTag(29);
- output.WriteFloat(ReplyValue1);
- }
- if (ReplyValue2 != 0F) {
- output.WriteRawTag(37);
- output.WriteFloat(ReplyValue2);
- }
- if (ReplyValue3 != 0F) {
- output.WriteRawTag(45);
- output.WriteFloat(ReplyValue3);
+ if (ReplyMessage.Length != 0) {
+ output.WriteRawTag(26);
+ output.WriteString(ReplyMessage);
}
+ replyValue_.WriteTo(output, _repeated_replyValue_codec);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -198,15 +175,10 @@ namespace Tango.PMR.Stubs {
if (Time != 0) {
size += 1 + pb::CodedOutputStream.ComputeInt32Size(Time);
}
- if (ReplyValue1 != 0F) {
- size += 1 + 4;
- }
- if (ReplyValue2 != 0F) {
- size += 1 + 4;
- }
- if (ReplyValue3 != 0F) {
- size += 1 + 4;
+ if (ReplyMessage.Length != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeStringSize(ReplyMessage);
}
+ size += replyValue_.CalculateSize(_repeated_replyValue_codec);
return size;
}
@@ -221,15 +193,10 @@ namespace Tango.PMR.Stubs {
if (other.Time != 0) {
Time = other.Time;
}
- if (other.ReplyValue1 != 0F) {
- ReplyValue1 = other.ReplyValue1;
- }
- if (other.ReplyValue2 != 0F) {
- ReplyValue2 = other.ReplyValue2;
- }
- if (other.ReplyValue3 != 0F) {
- ReplyValue3 = other.ReplyValue3;
+ if (other.ReplyMessage.Length != 0) {
+ ReplyMessage = other.ReplyMessage;
}
+ replyValue_.Add(other.replyValue_);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -248,16 +215,13 @@ namespace Tango.PMR.Stubs {
Time = input.ReadInt32();
break;
}
- case 29: {
- ReplyValue1 = input.ReadFloat();
+ case 26: {
+ ReplyMessage = input.ReadString();
break;
}
+ case 34:
case 37: {
- ReplyValue2 = input.ReadFloat();
- break;
- }
- case 45: {
- ReplyValue3 = input.ReadFloat();
+ replyValue_.AddEntriesFrom(input, _repeated_replyValue_codec);
break;
}
}